
``nistitl`` is written and maintained by Olivier Heurtier.

Contributors
------------

- Oivier Heurtier <olivier.heurtier@idemia.com> `@olivier-heurtier-idemia <https://github.com/olivier-heurtier-idemia>`_

